postgleam/codec/defaults

Values

pub fn build_registry() -> dict.Dict(Int, codec.Codec)

Build the full registry including scalar codecs and array codecs. Array codecs are post-registered because they need element codecs from the base registry.

pub fn matchers() -> List(codec.CodecMatcher)

Returns the default list of codec matchers

Search Document