postgleam/type_info
Types
Information about a PostgreSQL type, queried from pg_type catalog
pub type TypeInfo {
TypeInfo(
oid: Int,
type_name: String,
send: String,
receive: String,
output: String,
input: String,
array_elem: Int,
base_type: Int,
comp_elems: List(Int),
)
}
Constructors
-
TypeInfo( oid: Int, type_name: String, send: String, receive: String, output: String, input: String, array_elem: Int, base_type: Int, comp_elems: List(Int), )Arguments
- array_elem
-
If this is an array type, the element type’s OID (0 if not array)
- base_type
-
If this is a range type, the base type’s OID (0 if not range)
- comp_elems
-
If this is a composite type, the element OIDs